pygeodesy.geodesicx.gxarea

Package pygeodesy :: Package geodesicx :: Module gxarea |
[frames] | no frames]

# Module gxarea

Slightly enhanced versions of classes PolygonArea and `Accumulator` from Karney's Python geographiclib.

Class GeodesicAreaExact is intended to work with instances of class GeodesicExact and of wrapped class `Geodesic`, see module pygeodesy.karney.

Copyright (C) Charles Karney (2008-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Version: 25.12.23

Classes
| GeodesicAreaExact Area and perimeter of a geodesic polygon, an enhanced version of Karney's Python class PolygonArea using the more accurate surface area.
| PolygonArea For `geographiclib` compatibility, sub-class of GeodesicAreaExact.